.. _legacy-transform-schemas:

Legacy Transform Schemas
========================

The legacy ``transform`` schemas:

.. asdf-autoschemas::

    add-1.0.0
    add-1.1.0
    affine-1.0.0
    affine-1.2.0
    airy-1.0.0
    airy-1.1.0
    bonne_equal_area-1.1.0
    bonne_equal_area-1.2.0
    cobe_quad_spherical_cube-1.0.0
    cobe_quad_spherical_cube-1.1.0
    compose-1.0.0
    compose-1.1.0
    concatenate-1.0.0
    concatenate-1.1.0
    conic_equal_area-1.0.0
    conic_equal_area-1.1.0
    conic_equal_area-1.2.0
    conic_equidistant-1.0.0
    conic_equidistant-1.1.0
    conic_equidistant-1.2.0
    conic_orthomorphic-1.0.0
    conic_orthomorphic-1.1.0
    conic_orthomorphic-1.2.0
    conic_perspective-1.0.0
    conic_perspective-1.1.0
    conic_perspective-1.2.0
    conic-1.0.0
    conic-1.1.0
    conic-1.2.0
    constant-1.0.0
    constant-1.1.0
    constant-1.2.0
    constant-1.3.0
    cylindrical_equal_area-1.0.0
    cylindrical_equal_area-1.1.0
    cylindrical_equal_area-1.2.0
    cylindrical_perspective-1.0.0
    cylindrical_perspective-1.1.0
    cylindrical_perspective-1.2.0
    cylindrical-1.0.0
    cylindrical-1.1.0
    divide-1.0.0
    divide-1.1.0
    fix_inputs-1.1.0
    gnomonic-1.0.0
    gnomonic-1.1.0
    hammer_aitoff-1.0.0
    hammer_aitoff-1.1.0
    healpix-1.0.0
    healpix-1.1.0
    identity-1.0.0
    identity-1.1.0
    label_mapper-1.0.0
    label_mapper-1.1.0
    mercator-1.0.0
    mercator-1.1.0
    molleweide-1.0.0
    molleweide-1.1.0
    multiply-1.0.0
    multiply-1.1.0
    parabolic-1.0.0
    parabolic-1.1.0
    plate_carree-1.0.0
    plate_carree-1.1.0
    polyconic-1.0.0
    polyconic-1.1.0
    polynomial-1.0.0
    polynomial-1.1.0
    power-1.0.0
    power-1.1.0
    pseudoconic-1.0.0
    pseudoconic-1.1.0
    pseudocylindrical-1.0.0
    pseudocylindrical-1.1.0
    quad_spherical_cube-1.0.0
    quad_spherical_cube-1.1.0
    quadcube-1.0.0
    quadcube-1.1.0
    regions_selector-1.0.0
    regions_selector-1.1.0
    remap_axes-1.0.0
    remap_axes-1.1.0
    remap_axes-1.2.0
    rotate2d-1.0.0
    rotate2d-1.1.0
    rotate2d-1.2.0
    rotate3d-1.0.0
    rotate3d-1.1.0
    rotate3d-1.2.0
    sanson_flamsteed-1.0.0
    sanson_flamsteed-1.1.0
    scale-1.0.0
    scale-1.1.0
    shift-1.0.0
    shift-1.1.0
    slant_orthographic-1.0.0
    slant_orthographic-1.1.0
    slant_zenithal_perspective-1.0.0
    slant_zenithal_perspective-1.1.0
    stereographic-1.0.0
    stereographic-1.1.0
    subtract-1.0.0
    subtract-1.1.0
    tabular-1.0.0
    tabular-1.1.0
    tangential_spherical_cube-1.0.0
    tangential_spherical_cube-1.1.0
    transform-1.0.0
    transform-1.1.0
    zenithal_equal_area-1.0.0
    zenithal_equal_area-1.1.0
    zenithal_equidistant-1.0.0
    zenithal_equidistant-1.1.0
    zenithal_perspective-1.0.0
    zenithal_perspective-1.1.0
    zenithal_perspective-1.2.0
    zenithal-1.0.0
    zenithal-1.1.0
